import React, { Component } from 'react';
import { Percent } from '../../../src/react-progressor';

class PercentDemo extends Component {
  constructor(props) {
    super(props);
    this.state = {
      // shouldn't be in state really but whatever
      start: (new Date()).getTime(),
      now: (new Date()).getTime()
    }
  }
  
  tick() {
    const now = (new Date()).getTime();
    this.setState({
      now,
    });
  }
  
  componentDidMount() {
    this.interval = setInterval(() => this.tick(), 1000);
  }
  
  componentWillUnmount() {
    clearInterval(this.interval);
  }
  
  render() {
    const fiveDays = 1000 * 60 * 60 * 24 * 5;
    const start = this.state.start - fiveDays;
    const end = this.state.start + fiveDays;
    return (
      <div>
        <h2>Percent Container</h2>
        <p>Displays percent as a number</p>
        <h3>Simple Example</h3>
        <Percent current={30} />
        <pre><code>
          {"<Percent current={30} />"}
        </code></pre>
        <h3>Kitchen Sink Example</h3>
        <Percent start={start} end={end} current={this.state.now} places={6} />
        <pre><code>
{`
// in tick() function, called every second
const now = (new Date()).getTime();
this.setState({
  now: now,
});
// in render() function
const fiveDays = 1000 * 60 * 60 * 24 * 5;
const start = this.state.now - fiveDays;
const end = this.state.now + fiveDays;
<Percent start={start} end={end} current={now} places={6} />
`}
        </code></pre>
        <h3>Properties</h3>
        <table>
          <thead>
            <tr>
              <th>Name</th>
              <th>Type</th>
              <th>Default</th>
              <th>Description</th>
            </tr>
          </thead>
          <tbody>
            <tr>
              <td>start</td>
              <td>Number</td>
              <td>0</td>
              <td>Starting point</td>
            </tr>
          </tbody>
        </table>
      </div>
    );
  }
}

export default PercentDemo;