'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _util = require('../util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var ProgressBar = function ProgressBar(props) {
  var height = props.height;
  var bgColor = props.bgColor;
  var activeColor = props.activeColor;
  var textColor = props.textColor;
  var displayNum = props.displayNum;
  var threshold = props.threshold;
  var start = props.start;
  var end = props.end;
  var current = props.current;


  var percent = (0, _util.getPercent)(start, end, current);

  var outerStyles = {
    width: '100%',
    height: height + 'px',
    backgroundColor: bgColor,
    borderRadius: height / 8 + 'px'
  };

  var width = percent;
  if (percent > 100) {
    width = 100;
  }
  var innerStyles = {
    width: width + '%',
    height: height + 'px',
    backgroundColor: activeColor,
    color: textColor,
    textAlign: 'center',
    lineHeight: height + 'px',
    fontSize: height * 0.5 + 'px',
    borderRadius: height / 8 + 'px',
    transition: 'all 0.3s'
  };

  var innerText = '';
  if (percent >= threshold && displayNum) {
    innerText = percent + '%';
  }

  return _react2.default.createElement(
    'div',
    { style: outerStyles },
    _react2.default.createElement(
      'div',
      { style: innerStyles },
      innerText
    )
  );
};

ProgressBar.defaultProps = {
  height: 30,
  bgColor: '#eee',
  activeColor: '#5bc0de',
  textColor: 'white',
  displayNum: false,
  threshold: 10,
  start: 0,
  end: 100
};

ProgressBar.propTypes = {
  height: _react.PropTypes.number.isRequired,
  bgColor: _react.PropTypes.string.isRequired,
  activeColor: _react.PropTypes.string.isRequired,
  textColor: _react.PropTypes.string.isRequired,
  displayNum: _react.PropTypes.bool.isRequired,
  threshold: _react.PropTypes.number.isRequired,
  start: _react.PropTypes.number.isRequired,
  end: _react.PropTypes.number.isRequired,
  current: _react.PropTypes.number.isRequired
};

exports.default = ProgressBar;