'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _util = require('../util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var ProgressCircle = function ProgressCircle(props) {
  var radius = props.radius;
  var barWidth = props.barWidth;
  var bgColor = props.bgColor;
  var activeColor = props.activeColor;
  var textColor = props.textColor;
  var displayNum = props.displayNum;
  var start = props.start;
  var end = props.end;
  var current = props.current;


  var percent = (0, _util.getPercent)(start, end, current);

  var innerR = radius - barWidth;

  var outerStyles = {
    position: 'relative',
    color: textColor
  };

  var svgStyles = {
    height: 2 * radius + 'px',
    transform: 'rotate(-90deg) scaleY(-1)'
  };

  var circum = innerR * 2 * Math.PI;
  var offset = circum - circum * (percent / 100);
  // if greater than 100%
  if (offset < 0) {
    offset = 0;
  }
  var innerStyles = {
    fill: 'none',
    stroke: activeColor,
    strokeDashoffset: offset,
    strokeDasharray: circum,
    // I don't know strokeWidth needs to be * 2 but it works
    strokeWidth: barWidth * 2 + 'px',
    transition: 'all 0.3s'
  };
  var bgCircleStyles = {
    fill: 'none',
    stroke: bgColor,
    strokeDasharray: circum,
    strokeWidth: barWidth * 2 + 'px'
  };
  var textStyles = {
    position: 'absolute',
    top: 0,
    lineHeight: radius * 2 + 'px',
    width: radius * 2 + 'px',
    textAlign: 'center',
    fontSize: radius / 3 + 'px'
  };

  var innerText = '';
  if (displayNum) {
    innerText = percent + '%';
  }

  return _react2.default.createElement(
    'div',
    { style: outerStyles },
    _react2.default.createElement(
      'svg',
      { style: svgStyles, viewBox: '0 0 ' + 2 * radius + ' ' + 2 * radius, xmlns: 'http://www.w3.org/2000/svg' },
      _react2.default.createElement('circle', { style: bgCircleStyles, cx: radius, cy: radius, r: innerR }),
      _react2.default.createElement('circle', { style: innerStyles, cx: radius, cy: radius, r: innerR })
    ),
    _react2.default.createElement(
      'div',
      { style: textStyles },
      innerText
    )
  );
};

ProgressCircle.defaultProps = {
  radius: 60,
  barWidth: 8,
  bgColor: '#eee',
  activeColor: '#5bc0de',
  textColor: 'black',
  displayNum: false,
  start: 0,
  end: 100
};

ProgressCircle.propTypes = {
  radius: _react.PropTypes.number.isRequired,
  barWidth: _react.PropTypes.number.isRequired,
  bgColor: _react.PropTypes.string.isRequired,
  activeColor: _react.PropTypes.string.isRequired,
  textColor: _react.PropTypes.string.isRequired,
  displayNum: _react.PropTypes.bool.isRequired,
  start: _react.PropTypes.number.isRequired,
  end: _react.PropTypes.number.isRequired,
  current: _react.PropTypes.number.isRequired
};

exports.default = ProgressCircle;